@@ -3,7 +3,10 @@ Possibly could use a better name. These are instead alert functions that
 utilize the Slack operators. Extended from the medium article found in the README.
 """
 from airflow.hooks.base_hook import BaseHook
-from airflow.contrib.operators.slack_webhook_operator import SlackWebhookOperator
+try:
+    from airflow.contrib.operators.slack_webhook_operator import SlackWebhookOperator
+except Exception:
+    from airflow.providers.slack_webhook_operator import SlackWebhookOperator
 
 # This should match the connection ID created in the Medium article
 SLACK_CONN_ID = "slack"
